Confidence intervals for Rosenthal's fail-safe number assuming a half normal distribution with a random number of studies.
halfnorm.randomnr.ci(stat, se, alpha = 0.05, type = "dist")A list including:
Rosenthal's fail safe number.
The variance of Rosenthal's fail safe number.
The (1-alpha)% confidence interval for the true Rosenthal's fail safe number.
A vector with the statistics.
A vector with the standard errors of the stat.
The significance level, set to 0.05 by default.
The type of confidence intervals to construct. Based on distributional assumptions ("dist") or based on the method of moments ("mom") or both "both".
Michail Tsagris and Constantinos Frangos
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr and Constantinos Frangos kfragkos@outlook.com.
The function computes confidence intervals assuming a half normal distribution assuming that the number of studies is random and estimating the variance either via MLE or moments or bootstrap as described in Fragkos, Tsagris & Frangos (2014).
Konstantinos C. Fragkos, Michail Tsagris and Christos C. Frangos (2014). Publication Bias in Meta-Analysis: Confidence Intervals for Rosenthal's Fail-Safe Number. International Scholarly Research Notices, Volume 2014.
halfnorm.fixednr.ci den.plot, rosenthal,
convergence.rate
stat <- rnorm(30, 3, 0.2)
se <- rchisq(30, 1)
halfnorm.fixednr.ci(stat, se)
Run the code above in your browser using DataLab