Learn R Programming

fsn (version 0.4)

Density of Nr assuming a truncated normal or a folded normal: Density of Nr assuming a truncated normal or a folded normal

Description

Density of Nr assuming a truncated normal or a folded normal.

Usage

truncnorm.nr.density(nr, k, alpha = 0.05)
foldnorm.nr.density(nr, k, alpha = 0.05)

Value

The density value of Nr assuming either a truncated normal or a folded normal.

Arguments

nr

The value of Nr, which must be positive aparently.

k

The number of studies.

alpha

The significance level, set to 0.05 by default.

Author

Michail Tsagris, Constantinos Frangos, and Christos Frangos.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr, Constantinos Frangos kfragkos@outlook.com and Christos Frangos cfragos@teiath.gr.

Details

The function calculates the density of Nr assuming either a truncated normal (Equation (9)) or a folded normal (Equation (15)) in Fragkos, Tsagris & Frangos (2017).

References

Konstantinos C. Fragkos, Michail Tsagris and Christos C. Frangos (2017). Exploring the distribution for the estimator of Rosenthal's "fail-safe" number of unpublished studies in meta-analysis. Communications in Statistics-Theory and Methods, 46(11):5672--5684.

See Also

den.plot, rosenthal, convergence.rate

Examples

Run this code
truncnorm.nr.density(100, k = 30)
foldnorm.nr.density(100, k = 30)

Run the code above in your browser using DataLab