Numerical estimation of the convergence rate of Rosenthal's fail-safe number Nr: Numerical estimation of the convergence rate of Rosenthal's fail-safe number Nr
Description
Numerical estimation of the convergence rate of Rosenthal's fail-safe number Nr.
Usage
convergence.rate(k = seq( 10, 5000, by = 10), R = 1000, alpha = 0.05)
Value
Two plots, the absolute relative error of Nr agains the number of studies and
the logarithm of absolute relative error against the logarithm of the number of
studies and the coefficients of the regression model of the second plot.
The second coefficient is the numerically estimated convergence rate of Nr.
This function replicates the Figures 6 and 5 in Fragkos, Tsagris and
Frangos (2017).
References
Konstantinos C. Fragkos, Michail Tsagris and Christos C. Frangos (2017).
Exploring the distribution for the estimator of Rosenthal's "fail-safe"
number of unpublished studies in meta-analysis. Communications in
Statistics-Theory and Methods, 46(11):5672--5684.