Learn R Programming

fsn (version 0.4)

Plot of both densities of Nr: Plot of both densities of Nr

Description

Plot of both densities of Nr.

Usage

den.plot(k, max_k = 20 * k, dist = "truncnorm")

Value

The density plot of Nr assuming either a truncated normal or a folded normal.

Arguments

k

The number of studies.

max_k

The maximum number for which the densities are calcualted. It is set to \(20k\) by default.

dist

The distribution to plot, either "truncnorm", "foldnorm" or "both".

Author

Michail Tsagris and Constantinos Frangos

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr and Constantinos Frangos kfragkos@outlook.com.

Details

The function plot the density of Nr assuming a truncated normal (Equation (9)) or a folded normal (Equation (15)) in Fragkos, Tsagris and Frangos (2017).

References

Konstantinos C. Fragkos, Michail Tsagris and Christos C. Frangos (2017). Exploring the distribution for the estimator of Rosenthal's "fail-safe" number of unpublished studies in meta-analysis. Communications in Statistics-Theory and Methods, 46(11):5672--5684.

See Also

truncnorm.nr.density, rosenthal

Examples

Run this code
den.plot(30, dist = "both")

Run the code above in your browser using DataLab